@@ -1,5 +1,6 @@
 import json
 import requests
+from datetime import datetime,timezone,timedelta
 from rest_framework import status
 try:
     from django.conf import settings
@@ -17,6 +18,8 @@ class API(object):
     _identity_token = None
     _auth_scope = None
 
+    global_session = requests.Session()
+
     try:
         _client_id = getattr(
             settings, 'OAUTH2_CLIENT_ID', _client_id)
@@ -55,30 +58,59 @@ class API(object):
         return self
 
     def refresh_identity_token(self):
-        _payload = {
-            'grant_type': 'client_credentials',
-            'scope': self._auth_scope,
-            'client_id': self._client_id,
-            'client_secret': self._client_secret
-        }
-        self._identity_token = requests.request(
-            "POST", self._auth_token_url, data=_payload)
+        refresh_token=False
+        # check if an Authorization header was set in the global token
+        if self.global_session.headers.get('Authorization'):
+            # check when it was set to expire which is set in '%H:%M:%S'
+            auth_expires_in=self.global_session.headers.get('auth_expires_in')
+            # convert the string '%H:%M:%S' to time
+            auth_expires_in=datetime.strptime(auth_expires_in, '%H:%M:%S').time()
+            # get the current time and add ten minutes to it, so that we refresh the token 10 minutes before its expiry
+            current_time=(datetime.now(timezone.utc) + timedelta(minutes=5)).time()
+            # if current time plus 10 minutes is more than when the auth needs to expire
+            # refresh the token
+            if current_time > auth_expires_in:
+                # first set the Authorization to an empty string
+                self.global_session.headers.update({'Authorization': ''})
+                refresh_token=True
+        # If the Authorization header was not set in the global token
+        else:
+            refresh_token=True
+            
+        if refresh_token:
+            _payload = {
+                'grant_type': 'client_credentials',
+                'scope': self._auth_scope,
+                'client_id': self._client_id,
+                'client_secret': self._client_secret
+            }
+            self._identity_token = requests.request(
+                "POST", self._auth_token_url, data=_payload)                
+                
+            if self._identity_token.status_code == 200:                
+                self.global_session.headers.update({
+                    'Authorization':f"{self._identity_token.json().get('access_token',None)}",
+                    'auth_expires_in':(datetime.now(timezone.utc) + timedelta(seconds=self._identity_token.json().get('expires_in',0))).strftime("%H:%M:%S")
+                })  
+
+                print(f'auth_expires_in: {self.global_session.headers["auth_expires_in"]}')
 
     # There are 3 types of API requests that most APIs use, POST, GET and PUT
     # This method will take the payload or data to be sent and send it to the required API url
     # using the desired method and returns the response
     def api_request(self, payload, method, verify = False, files = None):
+        # Authenticate this service on the Nash Identity Server
+        self.refresh_identity_token()
         
         if payload == "null":
             self._payload=json.dumps({})
         else:
             self._payload = payload
         
-        if self._headers is not None and self.get_identity_token is not None:
-            if self.get_identity_token.status_code == 200:
-                self._headers.update({
-                    'Authorization':f"Bearer {self.get_identity_token.json().get('access_token',None)}"
-                })
+        if self._headers is not None and self.global_session.headers.get('Authorization'):
+            self._headers.update({
+                'Authorization':f"Bearer {self.global_session.headers.get('Authorization')}"
+            })
         
         try:
             if method == 'POST':
