@@ -23,7 +23,8 @@ def is_authenticated(access_token):
     if access_token is not None:
         try:
             # _, token = access_token.split(' ')
-            decoded = jwt.decode(access_token, options={"verify_signature": False})
+            decoded = jwt.decode(access_token, options={
+                                 "verify_signature": False})
             OAUTH2_SCOPE = getattr(settings, 'OAUTH2_SCOPE', None)
 
             if OAUTH2_SCOPE in decoded.get('scope', []):
@@ -31,5 +32,5 @@ def is_authenticated(access_token):
         except Exception as e:
             print(f'is_authenticated: {e}')
             return False
-    
+
     return False
