@@ -1,3 +1,4 @@
+from pickle import GLOBAL
 from bank_sync.Resources.banks import Bank
 from bank_sync.Resources.resource import Resource
 
@@ -40,7 +41,7 @@ class Nash(Resource):
 
         return self
 
-    def bank(self, bank_id=None):
+    def bank(self, bank_id=0):
 
         if self._bank is None:
             self._bank = Bank(self, bank_id)
