@@ -17,6 +17,23 @@ class Accounts(Resource):
     urls = {}
     bank_sync_call_back = {}
 
+    full_statement_transaction_dict = {
+        "currency_code": "",
+        "date": "",
+        "description": "",
+        "transaction_id": "",
+        "reference": "",
+        "value_date": "",
+        "posted_date": "",
+        "service_point": "",
+        "running_cleared_balance": "",
+        "debit_limit": 0,
+        "limit_expiry_date": "",
+        "serial": "",
+        "amount": "",
+        "type": "",
+    }
+
     try:
         bank_sync_call_back = getattr(
             settings, 'BANK_SYNC_CALL_BACK_URLS', bank_sync_call_back)
@@ -213,6 +230,9 @@ class Accounts(Resource):
 
         return data
 
+    def get_full_statement_transaction_dict(self):
+        return self.full_statement_transaction_dict
+
     def response(self):
 
         data = {}
@@ -221,21 +241,61 @@ class Accounts(Resource):
 
         if super().get_operation() == super().BALANCE:
 
+            data.update({
+                "message": "",
+                "code": -111111,
+                "balance": 0,
+                "balance_time": "",
+                "account_type": "",
+                "cleared_balance": "",
+                "booked_balance": "",
+                "blocked_balance": "",
+                "arrears_amount": "",
+                "branch_name": "",
+                "branch_code": "",
+                "average_balance": "",
+                "uncleared_balance": "",
+                "over_draft_limit": "",
+                "credit_limit": "",
+            })
+
             if super().get_bank_id() == super().COOP:
 
                 data["message"] = response_data.get("MessageDescription", "")
-                data["code"] = response_data.get("MessageCode", "-111111")
+                data["code"] = int(response_data.get("MessageCode", -111111))
                 data["balance"] = response_data.get("AvailableBalance", "")
+                data["balance_time"] = response_data.get("MessageDateTime", "")
+
+                data["account_type"] = response_data.get("ProductName", "")
+                data["cleared_balance"] = response_data.get(
+                    "ClearedBalance", "")
+                data["booked_balance"] = response_data.get("BookedBalance", "")
+                data["blocked_balance"] = response_data.get(
+                    "BlockedBalance", "")
+                data["arrears_amount"] = response_data.get("ArrearsAmount", "")
+                data["branch_name"] = response_data.get("BranchName", "")
+                data["branch_code"] = response_data.get("BranchSortCode", "")
+                data["average_balance"] = response_data.get(
+                    "AverageBalance", "")
+                data["uncleared_balance"] = response_data.get(
+                    "UnclearedBalance", "")
+                data["over_draft_limit"] = response_data.get("ODLimit", "")
+                data["credit_limit"] = response_data.get("CreditLimit", "")
 
             elif super().get_bank_id() == super().EQUITY:
 
                 data["message"] = response_data.get("message", "")
                 data["code"] = response_data.get("code", -111111)
-                if bool(response_data.get("data", {}).get("balances", [])):
-                    data["balance"] = response_data.get("data", {}).get(
-                        "balances", [])[0].get("amount", -1)
-                else:
-                    data["balance"] = 0
+                data["balance_time"] = response_data.get("response_time", "")
+
+                data["balance"] = 0
+
+                balances = response_data.get("data", {}).get("balances", [])
+                if bool(balances):
+                    if balances[0].get('type', '') == 'Available':
+                        data["balance"] = balances[0].get("amount", -1)
+                    if balances[1].get('type', '') == 'Current':
+                        data["cleared_balance"] = balances[1].get("amount", -1)
             # If bank_id is UBA
             elif super().get_bank_id() == super().UBA:
 
@@ -244,6 +304,7 @@ class Accounts(Resource):
                     "return", {}).get("C24TRANRES", {}).get("ACTION_CODE", "-111111")))
                 data["balance"] = float(response_data.get("sendTransactionResponse", {}).get(
                     "return", {}).get("C24TRANRES", {}).get("AVAILABLE_BALANCE", -1))
+                data["balance_time"] = datetime.strptime(f'{response_data.get("sendTransactionResponse", {}).get("return", {}).get("C24TRANRES", {}).get("TRAN_DATE_TIME",)}', '%Y%d%m%H%M%S').strftime('%Y-%m-%d %H:%M:%S')
                 if data["code"]:
                     data["message"] = "Transaction Failed"
                 else:
@@ -341,16 +402,31 @@ class Accounts(Resource):
 
                 data["message"] = response_data.get("MessageDescription", "")
                 data["code"] = response_data.get("MessageCode", "-111111")
+                data["statement_time"] = response_data.get(
+                    "MessageDateTime", "")
+                data["statement_reference"] = response_data.get(
+                    "MessageReference", "")
                 data["transactions"] = []
 
                 transactions = response_data.get("Transactions", [])
 
                 for i in range(len(transactions)):
-                    transaction = {
-                        "currency_code": "KES",
-                        "date": transactions[i].get("TransactionDate", ""),
-                        "description": transactions[i].get("Narration", ""),
-                    }
+                    transaction={}
+                    transaction.update(self.get_full_statement_transaction_dict())
+
+                    transaction.update(
+                        {
+                            "currency_code": "KES",
+                            "date": transactions[i].get("TransactionDate", ""),
+                            "description": transactions[i].get("Narration", ""),
+                            "transaction_id": transactions[i].get("TransactionID", ""),
+                            "value_date": transactions[i].get("ValueDate", ""),
+                            "service_point": transactions[i].get("ServicePoint", ""),
+                            "running_cleared_balance": transactions[i].get("RunningClearedBalance", ""),
+                            "debit_limit": float(transactions[i].get("DebitLimit", -1)),
+                            "limit_expiry_date": transactions[i].get("LimitExpiryDate", ""),
+                        }
+                    )
 
                     if transactions[i].get("TransactionType", "") == "D":
                         transaction["amount"] = transactions[i].get(
@@ -365,7 +441,7 @@ class Accounts(Resource):
                     transaction["reference"] = transactions[i].get(
                         "TransactionReference", "")
                     transaction["running_balance"] = transactions[i].get(
-                        "RunningClearedBalance", "")
+                        "RunningBookBalance", "")
 
                     data["transactions"].append(transaction)
 
@@ -381,25 +457,35 @@ class Accounts(Resource):
                 if isinstance(response_data, dict):
                     data["message"] = response_data.get("message", "")
                     data["code"] = f'{response_data.get("code", -111111)}'
+                    data["statement_time"] = response_data.get(
+                        "response_time", "")
+                    data["statement_reference"] = ""
                     data["transactions"] = []
 
                     transactions = response_data.get(
                         "data", {}).get("transactions", [])
 
                     for i in range(len(transactions)):
+                        transaction={}
+                        transaction.update(self.get_full_statement_transaction_dict())
 
-                        transaction = {
+                        transaction.update({
                             "currency_code": response_data.get("data", {}).get("currency", "KES"),
                             "date": datetime.fromisoformat(
                                 transactions[i].get(
-                                    "postedDateTime", "") + '+00:00'
+                                    "date", "") + '+00:00'
                             ).strftime('%Y-%m-%d %H:%M:%S'),
                             "description": transactions[i].get("description", ""),
                             "amount":  f'{transactions[i].get("amount", "")}',
                             "type":  transactions[i].get("type", ""),
+                            "serial":  transactions[i].get("serial", ""),
                             "reference":  transactions[i].get("reference", ""),
-                            "running_balance":  f'{transactions[i].get("runningBalance", {}).get("amount", "")}'
-                        }
+                            "running_balance":  f'{transactions[i].get("runningBalance", {}).get("amount", "")}',
+                            "posted_date": datetime.fromisoformat(
+                                transactions[i].get(
+                                    "postedDateTime", "") + '+00:00'
+                            ).strftime('%Y-%m-%d %H:%M:%S'),
+                        })
 
                         data["transactions"].append(transaction)
                 else:
@@ -411,6 +497,7 @@ class Accounts(Resource):
                 data["message"] = ''
                 data["code"] = int(float(response_data.get("sendTransactionResponse", {}).get(
                     "return", {}).get("C24TRANRES", {}).get("ACTION_CODE", "-111111")))
+                data["statement_reference"] = f'{response_data.get("sendTransactionResponse", {}).get("return", {}).get("C24TRANRES", {}).get("STAN", "")}'
                 if data["code"]:
                     data["message"] = "Transaction Failed"
                 else:
@@ -421,19 +508,32 @@ class Accounts(Resource):
                     "C24TRANRES", {}).get("TRANS_INFO", {}).get("TRAN", {}).get("element", [])
 
                 for i in range(len(transactions)):
-                    transaction = {
-                        "date": datetime.strptime(f'{transactions[i].get("DATE_POSTED", None)}', '%Y%d%m%H%M%S').strftime('%Y-%m-%d %H:%M:%S'),
+                    transaction={}
+                    transaction.update(self.get_full_statement_transaction_dict())
+
+                    transaction.update({
+                        "currency_code": response_data.get("sendTransactionResponse", {}).get(
+                            "return", {}).get("C24TRANRES", {}).get("BALANCE_CURRENCY", "NGN"),
+                        "date": datetime.strptime(f'{transactions[i].get("TRAN_DATE", None)}', '%Y%d%m').strftime('%Y-%m-%d'),
+
                         "description": transactions[i].get("NARRATION", ""),
-                        "amount": transactions[i].get("TRAN_AMT", -1),
-                        "reference": transactions[i].get("TRAN_ID", ""),
-                        "running_balance": transactions[i].get("BALANCE", -1),
-                    }
+                        "amount": f'{transactions[i].get("TRAN_AMT", -1)}',
+                        "running_balance": f'{transactions[i].get("BALANCE", -1)}',
+
+                        "transaction_id": transactions[i].get("TRAN_ID", ""),
+                        "serial": f'{transactions[i].get("TRAN_SNUM", "")}',
+                        "value_date": datetime.strptime(f'{transactions[i].get("VALUE_DATE", None)}', '%Y%d%m').strftime('%Y-%m-%d'),
+                        "posted_date": datetime.strptime(f'{transactions[i].get("DATE_POSTED", None)}', '%Y%d%m%H%M%S').strftime('%Y-%m-%d %H:%M:%S'),
+                    })
 
                     if transactions[i].get("PART_TRAN_TYPE", "") == "D":
                         transaction["type"] = "Debit"
                     elif transactions[i].get("PART_TRAN_TYPE", "") == "C":
                         transaction["type"] = "Credit"
 
+                    if transactions[i].get("REF_NUM", {}).get("@null", "true") == "true":
+                        transaction["reference"] = ""
+
                     data["transactions"].append(transaction)
 
         elif super().get_operation() == super().PDF_TO_JSON or super().get_operation() == super().GET_JSON_PDF:
