@@ -744,7 +744,9 @@ class Payments(Resource):
 
         data = {
             "bank_id": super().get_bank_id(),
-            "type": super().get_operation()
+            "type": super().get_operation(),
+            "date":date.today().strftime('%d/%m/%y %H:%M:%S'),
+            "transaction_reference":"",
         }
 
         if not isinstance(response_data,dict):
