@@ -135,18 +135,21 @@ class Resource(API, Operations):
             endpoint = bank.get(self.get_action(), {}).get('endpoint', '')
 
             operation, method = bank.get(self.get_action(), {}).get(
-                'operations', {}).get(self.get_operation(), self.BANKS)
-
-            # Check if any query params where passed, while creating the end point
-            if bool(params):
-                endpoint = f'{endpoint}/{operation}?{params}'
+                'operations', {}).get(self.get_operation(), (-1,-1))
+            
+            if operation==-1 and method==-1:
+                self._response = {'error': f'Bank ID {self.get_bank_id()} Does not have Operation {self.get_operation()} in {self.get_action()} Entity'}
             else:
-                endpoint = f'{endpoint}/{operation}'
+                # Check if any query params where passed, while creating the end point
+                if bool(params):
+                    endpoint = f'{endpoint}/{operation}?{params}'
+                else:
+                    endpoint = f'{endpoint}/{operation}'
 
-            super().set_full_url(full_url=f"{bank.get('url','')}/{endpoint}")
+                super().set_full_url(full_url=f"{bank.get('url','')}/{endpoint}")
 
-            # Call the method exec to make the request to A.P.I. endpoint and return the data that will be returned in this method
-            self._response = self._exec(payload, method)
+                # Call the method exec to make the request to A.P.I. endpoint and return the data that will be returned in this method
+                self._response = self._exec(payload, method)
 
         else:
             self._response = {'error': 'Bank ID Does not Exist'}
