@@ -1,6 +1,6 @@
 from ast import literal_eval
 from bank_sync.models import RequestLogs, ResponseLogs
-from django.db import connection
+from django.db import connections
 
 class APILogsMiddleware:
 
@@ -46,11 +46,12 @@ class APILogsMiddleware:
             if len(request.body):
                 request_logs.body = literal_eval(request.body.decode("utf-8").replace("false","False").replace("true","True").replace("null","None"))
                 request_logs.save()
+                connections.close_all()
         except Exception as e:
             if request_logs is not None:
                 request_logs.error = e
                 request_logs.save()
-                connection.close()
+                connections.close_all()
 
     def log_response(self, response, ip):  
         response_logs = None      
@@ -59,8 +60,9 @@ class APILogsMiddleware:
             if len(response.data):
                 response_logs.content = response.data
                 response_logs.save()
+                connections.close_all()
         except Exception as e:
             if response_logs is not None:
                 response_logs.error = e
                 response_logs.save()
-                connection.close()
\ No newline at end of file
+                connections.close_all()
